@@ -1,6 +1,7 @@
 # -*- coding:utf-8 -*-
 
 # Copyright (c) 2009-2013 - Simon Conseil
+# Copyright (c) 2013      - Christophe-Marie Duquesne
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to
@@ -28,6 +29,8 @@ _DEFAULT_CONFIG = {
     'destination': '_build',
     'img_size': (640, 480),
     'img_processor': 'ResizeToFit',
+    'adjust_options': {'color': 1.0, 'brightness': 1.0,
+                       'contrast': 1.0, 'sharpness': 1.0},
     'make_thumbs': True,
     'thumb_prefix': '',
     'thumb_suffix': '',
@@ -37,21 +40,40 @@ _DEFAULT_CONFIG = {
     'keep_orig': False,
     'orig_dir': 'original',
     'jpg_options': {'quality': 85, 'optimize': True, 'progressive': True},
+    'webm_options': {'crf': '10', 'bitrate': '1.6M',
+                     'qmin': '4', 'qmax': '63'},
     'copyright': '',
-    'ext_list': ['.jpg', '.jpeg', '.JPG', '.JPEG', '.png'],
+    'img_ext_list': ['.jpg', '.jpeg', '.JPG', '.JPEG', '.png'],
+    'vid_ext_list': ['.MOV', '.mov', '.avi', '.mp4', '.webm', '.ogv'],
     'theme': 'colorbox',
     'write_html': True,
     'index_in_url': False,
+    'zip_gallery': False,
     'links': '',
-    'google_analytics': ''
+    'google_analytics': '',
+    'copy_exif_data': True,
+    'locale': ''
 }
 
 
 def get_thumb(settings, filename):
-    """Return the path to the thumb."""
+    """Return the path to the thumb.
+
+    examples:
+    >>> get_thumb(default_settings, "bar/foo.jpg")
+    "bar/thumbnails/foo.jpg"
+    >>> get_thumb(default_settings, "bar/foo.png")
+    "bar/thumbnails/foo.png"
+
+    for videos, it returns a jpg file:
+    >>> get_thumb(default_settings, "bar/foo.webm")
+    "bar/thumbnails/foo.jpg"
+    """
 
     path, filen = os.path.split(filename)
     name, ext = os.path.splitext(filen)
+    if ext in settings['vid_ext_list']:
+        ext = '.jpg'
     return os.path.join(path, settings['thumb_dir'], settings['thumb_prefix'] +
                         name + settings['thumb_suffix'] + ext)
 
@@ -98,4 +120,14 @@ def read_settings(filename=None):
             logger.warning("The %s setting should be specified with the "
                            "largest value first.", key)
 
+    if not settings['img_processor']:
+        logger.info('No Processor, images will not be resized')
+
+    return settings
+
+
+def create_settings(**kwargs):
+    """Create a new default setting copy and initialize it with kwargs."""
+    settings = _DEFAULT_CONFIG.copy()
+    settings.update(kwargs)
     return settings
