@@ -1,6 +1,7 @@
 # -*- coding:utf-8 -*-
 
 # Copyright (c) 2009-2013 - Simon Conseil
+# Copyright (c)      2013 - Christophe-Marie Duquesne
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to
@@ -24,6 +25,7 @@ from __future__ import absolute_import
 
 import codecs
 import copy
+import jinja2
 import logging
 import os
 import sys
@@ -33,7 +35,8 @@ from distutils.dir_util import copy_tree
 from jinja2 import Environment, FileSystemLoader, ChoiceLoader, PrefixLoader
 from jinja2.exceptions import TemplateNotFound
 
-from .image import generate_thumbnail
+import sigal.image
+import sigal.video
 from .settings import get_thumb, get_orig
 from .pkgmeta import __url__ as sigal_link
 
@@ -67,14 +70,21 @@ class Writer(object):
         default_loader = FileSystemLoader(
             os.path.join(THEMES_PATH, 'default', 'templates'))
 
+        # setup jinja env
+        env_options = {'trim_blocks': True}
+        try:
+            if tuple(int(x) for x in jinja2.__version__.split('.')) >= (2, 7):
+                env_options['lstrip_blocks'] = True
+        except ValueError:
+            pass
+
         env = Environment(
             loader=ChoiceLoader([
                 FileSystemLoader(theme_relpath),
                 default_loader,  # implicit inheritance
                 PrefixLoader({'!default': default_loader})  # explicit one
             ]),
-            trim_blocks=True,
-            lstrip_blocks=True
+            **env_options
         )
 
         try:
@@ -89,9 +99,9 @@ class Writer(object):
         self.ctx = {
             'sigal_link': sigal_link,
             'theme': {'name': os.path.basename(self.theme)},
-            'images': [],
+            'medias': [],
             'albums': [],
-            'breadcumb': ''
+            'breadcrumb': ''
         }
 
     def copy_assets(self):
@@ -100,11 +110,11 @@ class Writer(object):
         self.theme_path = os.path.join(self.output_dir, 'static')
         copy_tree(os.path.join(self.theme, 'static'), self.theme_path)
 
-    def get_breadcumb(self, paths, relpath):
+    def get_breadcrumb(self, paths, relpath):
         """Paths to upper directories (with titles and links)."""
 
         tmp_path = relpath
-        breadcumb = [((self.url_ext or '.'), paths[tmp_path]['title'])]
+        breadcrumb = [((self.url_ext or '.'), paths[tmp_path]['title'])]
 
         while True:
             tmp_path = os.path.normpath(os.path.join(tmp_path, '..'))
@@ -112,9 +122,9 @@ class Writer(object):
                 break
 
             url = os.path.relpath(tmp_path, relpath) + '/' + self.url_ext
-            breadcumb.append((url, paths[tmp_path]['title']))
+            breadcrumb.append((url, paths[tmp_path]['title']))
 
-        return reversed(breadcumb)
+        return reversed(breadcrumb)
 
     def generate_context(self, paths, relpath):
         """Generate the context dict for the given path."""
@@ -132,14 +142,29 @@ class Writer(object):
         ctx['theme']['url'] = os.path.relpath(self.theme_path, path)
 
         if relpath != '.':
-            ctx['breadcumb'] = self.get_breadcumb(paths, relpath)
+            ctx['breadcrumb'] = self.get_breadcrumb(paths, relpath)
 
-        for i in paths[relpath]['img']:
-            img_ctx = {'file': i,
-                       'thumb': get_thumb(self.settings, i)}
+        if len(paths[relpath]['medias']) > 0 and self.settings['zip_gallery']:
+            ctx['zip_gallery'] = self.settings['zip_gallery']
+
+        for i in paths[relpath]['medias']:
+            media_ctx = {}
+            base, ext = os.path.splitext(i)
+            if ext in self.settings['img_ext_list']:
+                media_ctx['type'] = 'img'
+                media_ctx['file'] = i
+
+                file_path = os.path.join(path, i)
+                raw, simple = sigal.image.get_exif_tags(file_path)
+                media_ctx['raw_exif'] = raw
+                media_ctx['exif'] = simple
+            else:
+                media_ctx['type'] = 'vid'
+                media_ctx['file'] = base + '.webm'
+            media_ctx['thumb'] = get_thumb(self.settings, i)
             if self.settings['keep_orig']:
-                img_ctx['big'] = get_orig(self.settings, i)
-            ctx['images'].append(img_ctx)
+                media_ctx['big'] = get_orig(self.settings, i)
+            ctx['medias'].append(media_ctx)
 
         for d in paths[relpath]['subdir']:
             dpath = os.path.normpath(os.path.join(relpath, d))
@@ -152,9 +177,15 @@ class Writer(object):
             # settings['make_thumbs'] is False)
             if not os.path.exists(thumb_path):
                 source = os.path.join(self.output_dir, dpath, alb_thumb)
-                generate_thumbnail(
-                    source, thumb_path, self.settings['thumb_size'], None,
-                    fit=self.settings['thumb_fit'])
+                base, ext = os.path.splitext(source)
+                if ext in self.settings['img_ext_list']:
+                    sigal.image.generate_thumbnail(
+                        source, thumb_path, self.settings['thumb_size'],
+                        fit=self.settings['thumb_fit'])
+                else:
+                    sigal.video.generate_thumbnail(
+                        source, thumb_path, self.settings['thumb_size'],
+                        fit=self.settings['thumb_fit'])
 
             ctx['albums'].append({
                 'url': d + '/' + self.url_ext,
